@@ -5,7 +5,7 @@ use strict;
 use OpenGuides::Utils;
 
 use vars qw( $VERSION );
-$VERSION = '0.10';
+$VERSION = '0.11';
 
 use Time::Piece;
 use URI::Escape;
@@ -83,7 +83,7 @@ sub emit_rdfxml {
 
     foreach my $var ( qw( phone fax website opening_hours_text address
                           postcode city country latitude longitude
-                          os_x os_y summary ) ) {
+                          os_x os_y map_link summary ) ) {
         my $val = $metadata{$var}[0] || $defaults{$var} || "";
         $tt_vars{$var} = $val;
     }
@@ -105,7 +105,7 @@ sub emit_rdfxml {
     # Check for geospatialness and define container object as appropriate.
     my $is_geospatial;
     foreach my $var ( qw( os_x os_y latitude longitude address postcode
-                          opening_hours_text ) ) {
+                          opening_hours_text map_link ) ) {
         $is_geospatial = 1 if $tt_vars{$var};
     }
 
@@ -283,7 +283,7 @@ The OpenGuides Project (openguides-dev@lists.openguides.org)
 
 =head1 COPYRIGHT
 
-Copyright (C) 2003-2007 The OpenGuides Project.  All Rights Reserved.
+Copyright (C) 2003-2008 The OpenGuides Project.  All Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
